Test if an object is a moat_audit
Examples
# This is an internal object structure, but can be tested:
audit <- moat:::moat_audit(risk = "low")
is_moat_audit(audit)
#> [1] TRUE
Test if an object is a moat_audit
# This is an internal object structure, but can be tested:
audit <- moat:::moat_audit(risk = "low")
is_moat_audit(audit)
#> [1] TRUE